@@ -1,9 +1,13 @@
+import json
 from pathlib import Path
+from pprint import pformat
 from typing import Any, Dict
 
 import yaml
 
 _YAML_SUFFIXES = ('yaml', 'yml', '.yaml', '.yml')
+_JSON_SUFFIXES = ('json', '.json')
+_DICT_SUFFIXES = ('dict',)
 
 
 def load_data(path: Path) -> Dict[str, Any]:
@@ -15,6 +19,9 @@ def load_data(path: Path) -> Dict[str, Any]:
     elif path.suffix in _YAML_SUFFIXES:
         with path.open() as stream:
             dictionary = yaml.safe_load(stream)
+    elif path.suffix in _JSON_SUFFIXES:
+        with path.open() as stream:
+            dictionary = json.load(stream)
     else:
         raise ValueError(f"File extension '{path.suffix}' is not supported.")
 
@@ -31,6 +38,18 @@ def print_data(data: Any, fmt: str) -> None:
             data=data,
             sort_keys=False,
         )
+    elif fmt in _JSON_SUFFIXES:
+        data = json.dumps(
+            obj=data,
+            indent=2,
+            sort_keys=False,
+            default=str,
+        )
+    elif fmt in _DICT_SUFFIXES:
+        data = pformat(
+            object=data,
+            sort_dicts=False,
+        )
     else:
         raise ValueError(f"Format '{fmt}' is not supported.")
 
@@ -49,5 +68,15 @@ def save_data(data: Dict[str, Any], path: Path) -> None:
                 stream=stream,
                 sort_keys=False,
             )
+    elif path.suffix in _JSON_SUFFIXES:
+        path.parent.mkdir(parents=True, exist_ok=True)
+        with path.open('w') as stream:
+            json.dump(
+                obj=data,
+                fp=stream,
+                indent=2,
+                sort_keys=False,
+                default=str,
+            )
     else:
         raise ValueError(f"File extension '{path.suffix}' is not supported.")
